@@ -47,7 +47,7 @@
 
 (eval-and-compile
   (defconst xcb:icccm:-atoms
-    '(UTF8_STRING COMPOUND_TEXT TEXT C_STRING
+    '(UTF8_STRING COMPOUND_TEXT TEXT C_STRING MANAGER
                   WM_PROTOCOLS WM_TAKE_FOCUS WM_DELETE_WINDOW WM_STATE)
     "Atoms involved in ICCCM.")
 
@@ -128,12 +128,10 @@ according to BYTE-ARRAY.
 This method automatically format the value as 8, 16 or 32 bits array."
   (let ((retval (cl-call-next-method obj byte-array))
         tmp)
-    (with-slots (~lsb length format bytes-after value-len value) obj
+    (with-slots (~lsb length format value-len value) obj
       (if (or (= 0 value-len) (= 0 length))
           (setf value nil)              ;no available value
-        (setq tmp (substring value
-                             0          ;long-offset
-                             (- (length value) bytes-after))
+        (setq tmp value                 ;long-offset is always 0
               value nil)
         (pcase format
           (8
