@@ -145,8 +145,7 @@ Consider let-bind it rather than change its global value."))
 (defclass xim:STRING (xim:-struct)
   ((length :initarg :length :type xcb:-u2)
    (string :initarg :string :type xcb:-ignore)
-   (string~ :initform '(name string type xim:LPCE
-                             size (xcb:-fieldref 'length))
+   (string~ :initform '(name string type xim:LPCE size (xcb:-fieldref 'length))
             :type xcb:-list)
    (pad~0 :initform '(xim:PADDING (+ 2 (xcb:-fieldref 'length)))
           :type xcb:-pad)))
@@ -418,8 +417,7 @@ Consider let-bind it rather than change its global value."))
    (number :initarg :number :type xcb:CARD16)
    (pad~0 :initform 2 :type xcb:-pad)
    (names :initarg :names :type xcb:-ignore)
-   (names~ :initform '(name names type xim:STRING
-                            size (xcb:-fieldref 'number))
+   (names~ :initform '(name names type xim:STRING size (xcb:-fieldref 'number))
            :type xcb:-list)))
 
 (defclass xim:auth-ng (xim:-request)
@@ -834,8 +832,7 @@ Consider let-bind it rather than change its global value."))
   ((flag :initform xim:commit-flag:x-lookup-chars)
    (length :initarg :length :type xcb:-u2)
    (string :initarg :string :type xcb:-ignore)
-   (string~ :initform '(name string type xcb:BYTE
-                             size (xcb:-fieldref 'length))
+   (string~ :initform '(name string type xcb:BYTE size (xcb:-fieldref 'length))
             :type xcb:-list)
    (pad~1 :initform '(xim:PADDING (xcb:-fieldref 'length)) :type xcb:-pad)))
 
@@ -858,8 +855,7 @@ Consider let-bind it rather than change its global value."))
    (ic-id :initarg :ic-id :type xcb:CARD16)
    (length :initarg :length :type xcb:-u2)
    (string :initarg :string :type xcb:-ignore)
-   (string~ :initform '(name string type xcb:BYTE
-                             size (xcb:-fieldref 'length))
+   (string~ :initform '(name string type xcb:BYTE size (xcb:-fieldref 'length))
             :type xcb:-list)
    (pad~0 :initform '(xim:PADDING (+ 2 (xcb:-fieldref 'length)))
           :type xcb:-pad)))
